require 'rails/generators'
module Appboost
  class InstallGenerator < Rails::Generators::Base
    desc "Generates unicorn conf and nginx conf"
    source_root File.join(File.dirname(__FILE__), '../../../templates')

    argument :host_base, type: :string, desc: 'Example: google.com'

    class_option :app_name,
      type: :string,
      default: Rails.application.class.to_s.split("::").first.downcase,
      aliases: '-a'

    class_option :host_root,
      type: :string,
      default: '/home/app',
      desc: 'Server root_path base',
      aliases: '-r' 

    class_option :listen,
      type: :numeric,
      default: 80,
      desc: "nginx listen port",
      aliases: '-p' 

    class_option :env,
      type: :string,
      default: Rails.env,
      desc: 'Rails environment',
      aliases: '-e'

    def server_name
      [rails_env, host_base].compact.join(".")
    end

    def app_name
      options[:app_name]
    end

    def app_env_name
      [app_name, rails_env].compact.join("-")
    end

    def generate_unicorn
      template "unicorn.rb.erb", "config/unicorn.rb"
    end

    def generate_nginx
      template "nginx_unicorn.conf.erb", "config/nginx/#{app_env_name}.conf"
    end

    private
      
      def rails_env
        options[:env] == "production" ? nil : options[:env]
      end
  end
end